@@ -1,3 +1,4 @@
+
 class _Node:
     def __init__(self, data=None, next=None):
         self.data = data
@@ -8,7 +9,7 @@ class List:
     def __init__(self):
         self.__head = None
 
-    def __repr__(self):
+    def __str__(self):
         l = "List : ["
         tmp = self.__head
         while tmp is not None:
@@ -42,6 +43,8 @@ class List:
         elif pos == 0:
             node.next = self.__head
             self.__head = node
+        elif pos == -1:
+            self.append(data)
         else:
             tmp = self.__head
             count = 0
@@ -78,6 +81,7 @@ class List:
                     tmp = tmp.next
                 data = tmp.data
                 cur.next = None
+                del tmp
                 return data
             while count < pos:
                 cur = tmp
@@ -92,13 +96,13 @@ class List:
     
     def delete(self, data):
         try:
-            if self.__head.data == data:
+            while self.__head.data == data:
                 ptr = self.__head
                 self.__head = self.__head.next
                 del ptr
             cur = self.__head
             tmp = cur.next
-            while tmp.next is not None:
+            while tmp is not None:
                 if tmp.data == data:
                     ptr = tmp
                     tmp = tmp.next
@@ -144,19 +148,13 @@ class List:
             prv = cur
             cur = nxt
         self.__head = prv
-        return self
-        
-        try:
-            lst = List()
-            while not self.empty():
-                lst.append(self.remove())
-            while not other.empty():
-                lst.append(other.remove())
-            return lst
-        except Exception as ex:
-            print("Error, %s" %ex, end=', ')
+    
+    def exchange(self, n):
+        for i in range(n):
+            self.append(self.remove())
+
     @classmethod
-    def merge(self, l1, l2):
+    def merge(cls, l1, l2):
         try:
             lst = List()
             tmp1 = l1.__head
@@ -171,8 +169,9 @@ class List:
             return lst
         except Exception as ex:
             print("Error, %s" %ex)
+
     @classmethod
-    def swap(self, l1, l2):
+    def swap(cls, l1, l2):
         bid = List()
         while not l1.empty():
             bid.append(l1.remove())
@@ -181,4 +180,3 @@ class List:
         while not bid.empty():
             l2.append(bid.remove())
         del bid
-    
\ No newline at end of file
