@@ -1,4 +1,5 @@
-import fds.stack
+from . import Stack
+
 
 class _Node:
     def __init__(self, data=None, next=None):
@@ -11,7 +12,7 @@ class Queue:
         self.__front = None
         self.__back = None
 
-    def __repr__(self):
+    def __str__(self):
         q = "Queue : ["
         tmp = self.__front
         while tmp is not None:
@@ -75,14 +76,19 @@ class Queue:
         return count
 
     def reverse(self):
-        stck = stack.Stack()
+        stck = Stack()
         while not self.empty():
             stck.push(self.enqueue())
         while not stck.empty():
             self.enqueue(stck.pop())
         return self
+    
+    def exchange(self, n):
+        for i in range(n):
+            self.enqueue(self.dequeue())
+
     @classmethod
-    def merge(self, q1, q2):
+    def merge(cls, q1, q2):
         try:
             que = Queue()
             tmp1 = q1.__front
@@ -97,8 +103,9 @@ class Queue:
             return que
         except Exception as ex:
             print("Error, %s" %ex)
+
     @classmethod
-    def swap(self, q1, q2):
+    def swap(cls, q1, q2):
         bid = Queue()
         while not q1.empty():
             bid.enqueue(q1.dequeue())
@@ -106,5 +113,4 @@ class Queue:
             q1.enqueue(q2.dequeue())
         while not bid.empty():
             q2.enqueue(bid.dequeue())
-        del bid
-    
\ No newline at end of file
+        del bid
\ No newline at end of file
