@@ -1,3 +1,4 @@
+
 class _Node:
     def __init__(self, data=None, next=None):
         self.data = data
@@ -8,7 +9,7 @@ class Stack:
     def __init__(self):
         self.__top = None
 
-    def __repr__(self):
+    def __str__(self):
         s = "Stack : ["
         tmp = self.__top
         while tmp is not None:
@@ -38,7 +39,6 @@ class Stack:
     def push(self, data):
         node = _Node(data, self.__top)
         self.__top = node
-        return self.__top
 
     def pop(self):
         ptr = self.__top
@@ -67,8 +67,21 @@ class Stack:
         while not self.empty():
             stck.push(self.pop())
         return stck
+    
+    def exchange(self, n):
+        bid1 = Stack()
+        bid2 = Stack()
+        for i in range(n):
+            bid1.push(self.pop())
+        while not self.empty():
+            bid2.push(self.pop())
+        while not bid1.empty():
+            self.push(bid1.pop())
+        while not bid2.empty():
+            self.push(bid2.pop())
+
     @classmethod
-    def merge(self, s1, s2):
+    def merge(cls, s1, s2):
         try:
             stck = Stack()
             tmp1 = s1.__top
@@ -83,8 +96,9 @@ class Stack:
             return stck
         except Exception as ex:
             print("Error, %s" %ex)
+
     @classmethod
-    def swap(self, s1, s2):
+    def swap(cls, s1, s2):
         bid1 = Stack()
         bid2 = Stack()
         while not s1.empty():
@@ -95,5 +109,4 @@ class Stack:
             s2.push(bid1.pop())
         while not bid2.empty():
             s1.push(bid2.pop())
-        del bid1, bid2
-    
\ No newline at end of file
+        del bid1, bid2
\ No newline at end of file
